@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.010';
+$Time::C::VERSION = '0.011';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -427,6 +427,13 @@ method diff ($t: $t2) {
     return Time::D->new($t->epoch, $epoch);
 }
 
+
+method clone($t:) {
+    my $c = ref $t;
+
+    return $c->localtime($t->epoch, $t->tz);
+}
+
 1;
 
 __END__
@@ -441,7 +448,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -850,12 +857,20 @@ The second is 0-based where second 0 is the first second of the minute. Legal va
 
 Creates a L<Time::D> object from C<$t1> and C<$t2> or C<$epoch>. It accepts either an arbitrary object that has an C<< ->epoch >> accessor returning an epoch, or a straight epoch.
 
+=head2 clone
+
+  my $t2 = $t1->clone();
+
+Returns a copy of C<$t1>.
+
 =head1 SEE ALSO
 
 =over
 
 =item L<Time::D>
 
+=item L<Time::R>
+
 =item L<Time::Moment>
 
 =item L<Time::Piece>
