@@ -1,7 +1,8 @@
 use strict;
 use warnings;
 package Time::C::Sentinel;
-$Time::C::Sentinel::VERSION = '0.010';
+$Time::C::Sentinel::VERSION = '0.011';
+use Carp qw/ croak /;
 use Exporter qw/ import /;
 
 our @EXPORT = qw/ sentinel /;
@@ -12,6 +13,8 @@ sub sentinel :lvalue {
     my $value = $args{value};
     my $set   = $args{set};
 
+    croak "sentinel: no setter given" unless defined $set;
+
     tie my $ret, __PACKAGE__, $value, $set;
 
     return $ret;
@@ -45,7 +48,7 @@ Time::C::Sentinel
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
