@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::D;
-$Time::D::VERSION = '0.010';
+$Time::D::VERSION = '0.011';
 # ABSTRACT: Differentiate between two times
 
 use overload (
@@ -238,7 +238,7 @@ Time::D - Differentiate between two times
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -330,7 +330,7 @@ If the form C<< $d->comp($new_comp) >> is used, it likewise changes the comp epo
 
   $d = $d->sign($new_sign);
 
-Returns or sets the sign part of the difference - whether the difference between C<< $d->base >> and C<< $d->comp >> is positive or negative. Changing it changes C<< $d->comp >> to either be before the base or after the C<< $d->base >>. The sign can be either C<+> or C<->.
+Returns or sets the sign part of the difference - whether the difference between C<< $d->base >> and C<< $d->comp >> is positive or negative. Changing it changes C<< $d->comp >> to either be before the C<< $d->base >> or after it. The sign can be either C<+> or C<->.
 
 If the form C<< $d->sign($new_sign) >> is used, it likewise changes the sign but returns the entire object.
 
